@@ -1,5 +1,3 @@
-/* $Xorg: XGetDCtl.c,v 1.4 2001/02/09 02:03:50 xorgcvs Exp $ */
-
 /************************************************************
 
 Copyright 1989, 1998  The Open Group
@@ -45,7 +43,6 @@ ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 SOFTWARE.
 
 ********************************************************/
-/* $XFree86: xc/lib/Xi/XGetDCtl.c,v 3.3 2001/12/14 19:55:13 dawes Exp $ */
 
 /***********************************************************************
  *
@@ -53,6 +50,10 @@ SOFTWARE.
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <X11/extensions/XI.h>
 #include <X11/extensions/XIproto.h>
 #include <X11/Xlibint.h>
@@ -62,10 +63,10 @@ SOFTWARE.
 #include "XIint.h"
 
 XDeviceControl *
-XGetDeviceControl(dpy, dev, control)
-    register Display *dpy;
-    XDevice *dev;
-    int control;
+XGetDeviceControl(
+    register Display	*dpy,
+    XDevice		*dev,
+    int			 control)
 {
     int size = 0;
     int nbytes, i;
@@ -87,19 +88,15 @@ XGetDeviceControl(dpy, dev, control)
     req->deviceid = dev->device_id;
     req->control = control;
 
-    if (!_XReply(dpy, (xReply *) & rep, 0, xFalse)) {
-	UnlockDisplay(dpy);
-	SyncHandle();
-	return (XDeviceControl *) NULL;
-    }
+    if (!_XReply(dpy, (xReply *) & rep, 0, xFalse))
+	goto out;
+
     if (rep.length > 0) {
 	nbytes = (long)rep.length << 2;
 	d = (xDeviceState *) Xmalloc((unsigned)nbytes);
 	if (!d) {
 	    _XEatData(dpy, (unsigned long)nbytes);
-	    UnlockDisplay(dpy);
-	    SyncHandle();
-	    return (XDeviceControl *) NULL;
+	    goto out;
 	}
 	sav = d;
 	_XRead(dpy, (char *)d, nbytes);
@@ -141,11 +138,9 @@ XGetDeviceControl(dpy, dev, control)
 	}
 
 	Device = (XDeviceControl *) Xmalloc((unsigned)size);
-	if (!Device) {
-	    UnlockDisplay(dpy);
-	    SyncHandle();
-	    return (XDeviceControl *) NULL;
-	}
+	if (!Device)
+	    goto out;
+
 	Sav = Device;
 
 	d = sav;
@@ -231,8 +226,9 @@ XGetDeviceControl(dpy, dev, control)
 	default:
 	    break;
 	}
-	XFree(sav);
     }
+out:
+    XFree(sav);
 
     UnlockDisplay(dpy);
     SyncHandle();
@@ -240,8 +236,7 @@ XGetDeviceControl(dpy, dev, control)
 }
 
 void
-XFreeDeviceControl(control)
-    XDeviceControl *control;
+XFreeDeviceControl(XDeviceControl *control)
 {
     XFree(control);
 }
